@@ -22,11 +22,11 @@ import threading
 from automaton import runners
 from concurrent import futures
 import fasteners
+import functools
 import networkx as nx
 from oslo_utils import excutils
 from oslo_utils import strutils
 from oslo_utils import timeutils
-import six
 
 from taskflow.engines.action_engine import builder
 from taskflow.engines.action_engine import compiler
@@ -65,7 +65,7 @@ def _pre_check(check_compiled=True, check_storage_ensured=True,
     def decorator(meth):
         do_what = meth.__name__
 
-        @six.wraps(meth)
+        @functools.wraps(meth)
         def wrapper(self, *args, **kwargs):
             if check_compiled and not self._compiled:
                 raise exc.InvalidState("Can not %s an engine which"
@@ -321,7 +321,7 @@ class ActionEngine(base.Engine):
             except Exception:
                 with excutils.save_and_reraise_exception():
                     LOG.exception("Engine execution has failed, something"
-                                  " bad must of happened (last"
+                                  " bad must have happened (last"
                                   " %s machine transitions were %s)",
                                   last_transitions.maxlen,
                                   list(last_transitions))
@@ -335,8 +335,8 @@ class ActionEngine(base.Engine):
                             e_failures = self.storage.get_execute_failures()
                             r_failures = self.storage.get_revert_failures()
                             er_failures = itertools.chain(
-                                six.itervalues(e_failures),
-                                six.itervalues(r_failures))
+                                e_failures.values(),
+                                r_failures.values())
                             failure.Failure.reraise_if_any(er_failures)
             finally:
                 if w is not None:
@@ -349,7 +349,7 @@ class ActionEngine(base.Engine):
         seen = set()
         dups = set()
         execution_graph = compilation.execution_graph
-        for node, node_attrs in execution_graph.nodes_iter(data=True):
+        for node, node_attrs in execution_graph.nodes(data=True):
             if node_attrs['kind'] in compiler.ATOMS:
                 atom_name = node.name
                 if atom_name in seen:
@@ -375,8 +375,8 @@ class ActionEngine(base.Engine):
     def _ensure_storage(self):
         """Ensure all contained atoms exist in the storage unit."""
         self.storage.ensure_atoms(
-            self._runtime.analyzer.iterate_nodes(compiler.ATOMS))
-        for atom in self._runtime.analyzer.iterate_nodes(compiler.ATOMS):
+            self._runtime.iterate_nodes(compiler.ATOMS))
+        for atom in self._runtime.iterate_nodes(compiler.ATOMS):
             if atom.inject:
                 self.storage.inject_atom_args(atom.name, atom.inject,
                                               transient=self._inject_transient)
@@ -402,7 +402,7 @@ class ActionEngine(base.Engine):
         last_cause = None
         last_node = None
         missing_nodes = 0
-        for atom in self._runtime.analyzer.iterate_nodes(compiler.ATOMS):
+        for atom in self._runtime.iterate_nodes(compiler.ATOMS):
             exec_missing = self.storage.fetch_unsatisfied_args(
                 atom.name, atom.rebind, optional_args=atom.optional)
             revert_missing = self.storage.fetch_unsatisfied_args(
@@ -594,7 +594,7 @@ String (case insensitive)    Executor used
         executor_cls = cls._default_executor_cls
         # Match the desired executor to a class that will work with it...
         desired_executor = options.get('executor')
-        if isinstance(desired_executor, six.string_types):
+        if isinstance(desired_executor, str):
             matched_executor_cls = None
             for m in cls._executor_str_matchers:
                 if m.matches(desired_executor):
