@@ -17,7 +17,6 @@
 import abc
 
 from oslo_utils import reflection
-import six
 
 # Link metadata keys that have inherent/special meaning.
 #
@@ -35,9 +34,15 @@ LINK_REASONS = 'reasons'
 # This key denotes a callable that will determine if the target is visited.
 LINK_DECIDER = 'decider'
 
+# Chop off full module names of patterns that are built-in to taskflow...
+_CHOP_PAT = "taskflow.patterns."
+_CHOP_PAT_LEN = len(_CHOP_PAT)
 
-@six.add_metaclass(abc.ABCMeta)
-class Flow(object):
+# This key denotes the depth the decider will apply (defaulting to all).
+LINK_DECIDER_DEPTH = 'decider_depth'
+
+
+class Flow(object, metaclass=abc.ABCMeta):
     """The base abstract class of all flow implementations.
 
     A flow is a structure that defines relationships between tasks. You can
@@ -53,7 +58,7 @@ class Flow(object):
     """
 
     def __init__(self, name, retry=None):
-        self._name = six.text_type(name)
+        self._name = str(name)
         self._retry = retry
         # NOTE(akarpinska): if retry doesn't have a name,
         # the name of its owner will be assigned
@@ -98,9 +103,20 @@ class Flow(object):
             * ``meta`` is link metadata, a dictionary.
         """
 
+    @abc.abstractmethod
+    def iter_nodes(self):
+        """Iterate over nodes of the flow.
+
+        Iterates over 2-tuples ``(A, meta)``, where
+            * ``A`` is a child (atom or subflow) of current flow;
+            * ``meta`` is link metadata, a dictionary.
+        """
+
     def __str__(self):
-        return "%s: %s(len=%d)" % (reflection.get_class_name(self),
-                                   self.name, len(self))
+        cls_name = reflection.get_class_name(self)
+        if cls_name.startswith(_CHOP_PAT):
+            cls_name = cls_name[_CHOP_PAT_LEN:]
+        return '"%s: %s(len=%d)"' % (cls_name, self.name, len(self))
 
     @property
     def provides(self):
