@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import contextlib
 import functools
 import sys
@@ -23,12 +24,12 @@ import fasteners
 import futurist
 from kazoo import exceptions as k_exceptions
 from kazoo.protocol import paths as k_paths
+from kazoo.protocol import states as k_states
 from kazoo.recipe import watchers
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
 
 from taskflow.conductors import base as c_base
 from taskflow import exceptions as excp
@@ -199,6 +200,9 @@ class ZookeeperJob(base.Job):
         return ((self.root, self.sequence, self.priority) ==
                 (other.root, other.sequence, other.priority))
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __hash__(self):
         return hash(self.path)
 
@@ -206,7 +210,7 @@ class ZookeeperJob(base.Job):
 class ZookeeperJobBoard(base.NotifyingJobBoard):
     """A jobboard backed by `zookeeper`_.
 
-    Powered by the `kazoo <http://kazoo.readthedocs.org/>`_ library.
+    Powered by the `kazoo <https://kazoo.readthedocs.io/en/latest/>`_ library.
 
     This jobboard creates *sequenced* persistent znodes in a directory in
     zookeeper and uses zookeeper watches to notify other jobboards of
@@ -239,7 +243,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
     specification
 
     .. _zookeeper: http://zookeeper.apache.org/
-    .. _json: http://json.org/
+    .. _json: https://json.org/
     """
 
     #: Transaction support was added in 3.4.0 so we need at least that version.
@@ -261,6 +265,19 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
     #: Default znode path used for jobs (data, locks...).
     DEFAULT_PATH = "/taskflow/jobs"
 
+    STATE_HISTORY_LENGTH = 2
+    """
+    Number of prior state changes to keep a history of, mainly useful
+    for history tracking and debugging connectivity issues.
+    """
+
+    NO_FETCH_STATES = (k_states.KazooState.LOST, k_states.KazooState.SUSPENDED)
+    """
+    Client states underwhich we return empty lists from fetching routines,
+    during these states the underlying connection either is being recovered
+    or may be recovered (aka, it has not full disconnected).
+    """
+
     def __init__(self, name, conf,
                  client=None, persistence=None, emit_notifications=True):
         super(ZookeeperJobBoard, self).__init__(name, conf)
@@ -298,6 +315,9 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
         self._worker = None
         self._emit_notifications = bool(emit_notifications)
         self._connected = False
+        self._suspended = False
+        self._closing = False
+        self._last_states = collections.deque(maxlen=self.STATE_HISTORY_LENGTH)
 
     def _try_emit(self, state, details):
         # Submit the work to the executor to avoid blocking the kazoo threads
@@ -334,10 +354,25 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
         return len(self._known_jobs)
 
     def _fetch_jobs(self, ensure_fresh=False):
-        if ensure_fresh:
-            self._force_refresh()
-        with self._job_cond:
-            return sorted(six.itervalues(self._known_jobs), reverse=True)
+        try:
+            last_state = self._last_states[0]
+        except IndexError:
+            last_state = None
+        if last_state in self.NO_FETCH_STATES:
+            # NOTE(harlowja): on lost clear out all known jobs (from the
+            # in-memory mapping) as we can not safely assume there are any
+            # jobs to continue working on in this state.
+            if last_state == k_states.KazooState.LOST and self._known_jobs:
+                # This will force the jobboard to drop all (in-memory) jobs
+                # that are not in this list (pretty much simulating what
+                # would happen if a jobboard data directory was emptied).
+                self._on_job_posting([], delayed=False)
+            return []
+        else:
+            if ensure_fresh:
+                self._force_refresh()
+            with self._job_cond:
+                return sorted(self._known_jobs.values())
 
     def _force_refresh(self):
         try:
@@ -364,12 +399,15 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
 
     def _remove_job(self, path):
         if path not in self._known_jobs:
-            return
+            return False
         with self._job_cond:
             job = self._known_jobs.pop(path, None)
         if job is not None:
             LOG.debug("Removed job that was at path '%s'", path)
             self._try_emit(base.REMOVAL, details={'job': job})
+            return True
+        else:
+            return False
 
     def _process_child(self, path, request, quiet=True):
         """Receives the result of a child data fetch request."""
@@ -387,23 +425,24 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             job_name = job_data['name']
         except (ValueError, TypeError, KeyError):
             with excutils.save_and_reraise_exception(reraise=not quiet):
-                LOG.warn("Incorrectly formatted job data found at path: %s",
-                         path, exc_info=True)
+                LOG.warning("Incorrectly formatted job data found at path: %s",
+                            path, exc_info=True)
         except self._client.handler.timeout_exception:
             with excutils.save_and_reraise_exception(reraise=not quiet):
-                LOG.warn("Operation timed out fetching job data from path: %s",
-                         path, exc_info=True)
+                LOG.warning("Operation timed out fetching job data from"
+                            " from path: %s",
+                            path, exc_info=True)
         except k_exceptions.SessionExpiredError:
             with excutils.save_and_reraise_exception(reraise=not quiet):
-                LOG.warn("Session expired fetching job data from path: %s",
-                         path, exc_info=True)
+                LOG.warning("Session expired fetching job data from path: %s",
+                            path, exc_info=True)
         except k_exceptions.NoNodeError:
             LOG.debug("No job node found at path: %s, it must have"
                       " disappeared or was removed", path)
         except k_exceptions.KazooException:
             with excutils.save_and_reraise_exception(reraise=not quiet):
-                LOG.warn("Internal error fetching job data from path: %s",
-                         path, exc_info=True)
+                LOG.warning("Internal error fetching job data from path: %s",
+                            path, exc_info=True)
         else:
             with self._job_cond:
                 # Now we can officially check if someone already placed this
@@ -439,7 +478,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
         investigate_paths = []
         pending_removals = []
         with self._job_cond:
-            for path in six.iterkeys(self._known_jobs):
+            for path in self._known_jobs.keys():
                 if path not in child_paths:
                     pending_removals.append(path)
         for path in child_paths:
@@ -456,8 +495,13 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
                 investigate_paths.append(path)
         if pending_removals:
             with self._job_cond:
-                for path in pending_removals:
-                    self._remove_job(path)
+                am_removed = 0
+                try:
+                    for path in pending_removals:
+                        am_removed += int(self._remove_job(path))
+                finally:
+                    if am_removed:
+                        self._job_cond.notify_all()
         for path in investigate_paths:
             # Fire off the request to populate this job.
             #
@@ -694,7 +738,28 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             kazoo_utils.checked_commit(txn)
 
     def _state_change_listener(self, state):
-        LOG.debug("Kazoo client has changed to state: %s", state)
+        if self._last_states:
+            LOG.debug("Kazoo client has changed to"
+                      " state '%s' from prior states '%s'", state,
+                      self._last_states)
+        else:
+            LOG.debug("Kazoo client has changed to state '%s' (from"
+                      " its initial/uninitialized state)", state)
+        self._last_states.appendleft(state)
+        if state == k_states.KazooState.LOST:
+            self._connected = False
+            # When the client is itself closing itself down this will be
+            # triggered, but in that case we expect it, so we don't need
+            # to emit a warning message.
+            if not self._closing:
+                LOG.warning("Connection to zookeeper has been lost")
+        elif state == k_states.KazooState.SUSPENDED:
+            LOG.warning("Connection to zookeeper has been suspended")
+            self._suspended = True
+        else:
+            # Must be CONNECTED then (as there are only 3 enums)
+            if self._suspended:
+                self._suspended = False
 
     def wait(self, timeout=None):
         # Wait until timeout expires (or forever) for jobs to appear.
@@ -729,6 +794,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
     def close(self):
         if self._owned:
             LOG.debug("Stopping client")
+            self._closing = True
             kazoo_utils.finalize_client(self._client)
         if self._worker is not None:
             LOG.debug("Shutting down the notifier")
@@ -738,6 +804,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             self._known_jobs.clear()
         LOG.debug("Stopped & cleared local state")
         self._connected = False
+        self._last_states.clear()
 
     @fasteners.locked(lock='_open_close_lock')
     def connect(self, timeout=10.0):
@@ -756,6 +823,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             if timeout is not None:
                 timeout = float(timeout)
             self._client.start(timeout=timeout)
+            self._closing = False
         except (self._client.handler.timeout_exception,
                 k_exceptions.KazooException):
             excp.raise_with_cause(excp.JobFailure,
