@@ -39,7 +39,7 @@ class GraphFlowTest(test.TestCase):
 
     def test_graph_flow_stringy(self):
         f = gf.Flow('test')
-        expected = 'graph_flow.Flow: test(len=0)'
+        expected = '"graph_flow.Flow: test(len=0)"'
         self.assertEqual(expected, str(f))
 
         task1 = _task(name='task1')
@@ -47,7 +47,7 @@ class GraphFlowTest(test.TestCase):
         task3 = _task(name='task3')
         f = gf.Flow('test')
         f.add(task1, task2, task3)
-        expected = 'graph_flow.Flow: test(len=3)'
+        expected = '"graph_flow.Flow: test(len=3)"'
         self.assertEqual(expected, str(f))
 
     def test_graph_flow_starts_as_empty(self):
@@ -85,7 +85,7 @@ class GraphFlowTest(test.TestCase):
         f = gf.Flow('test').add(task1, task2)
 
         self.assertEqual(2, len(f))
-        self.assertItemsEqual(f, [task1, task2])
+        self.assertCountEqual(f, [task1, task2])
         self.assertEqual([], list(f.iter_links()))
 
     def test_graph_flow_two_dependent_tasks(self):
@@ -94,7 +94,7 @@ class GraphFlowTest(test.TestCase):
         f = gf.Flow('test').add(task1, task2)
 
         self.assertEqual(2, len(f))
-        self.assertItemsEqual(f, [task1, task2])
+        self.assertCountEqual(f, [task1, task2])
         self.assertEqual([(task1, task2, {'reasons': set(['a'])})],
                          list(f.iter_links()))
 
@@ -107,7 +107,7 @@ class GraphFlowTest(test.TestCase):
         f = gf.Flow('test').add(task1).add(task2)
 
         self.assertEqual(2, len(f))
-        self.assertItemsEqual(f, [task1, task2])
+        self.assertCountEqual(f, [task1, task2])
         self.assertEqual([(task1, task2, {'reasons': set(['a'])})],
                          list(f.iter_links()))
 
@@ -167,7 +167,7 @@ class GraphFlowTest(test.TestCase):
 
         self.assertEqual(3, len(f))
 
-        self.assertItemsEqual(list(f.iter_links()), [
+        self.assertCountEqual(list(f.iter_links()), [
             (task1, task2, {'reasons': set(['a', 'b'])}),
             (task2, task3, {'reasons': set(['c'])})
         ])
@@ -178,7 +178,7 @@ class GraphFlowTest(test.TestCase):
         f = gf.Flow('test').add(task1, task2)
         linked = f.link(task1, task2)
         self.assertIs(linked, f)
-        self.assertItemsEqual(list(f.iter_links()), [
+        self.assertCountEqual(list(f.iter_links()), [
             (task1, task2, {'manual': True})
         ])
 
@@ -192,7 +192,7 @@ class GraphFlowTest(test.TestCase):
             'manual': True,
             'reasons': set(['a'])
         }
-        self.assertItemsEqual(list(f.iter_links()), [
+        self.assertCountEqual(list(f.iter_links()), [
             (task1, task2, expected_meta)
         ])
 
@@ -200,15 +200,15 @@ class GraphFlowTest(test.TestCase):
         task1 = _task('task1')
         task2 = _task('task2')
         f = gf.Flow('test').add(task2)
-        self.assertRaisesRegexp(ValueError, 'Node .* not found to link from',
-                                f.link, task1, task2)
+        self.assertRaisesRegex(ValueError, 'Node .* not found to link from',
+                               f.link, task1, task2)
 
     def test_graph_flow_link_to_unknown_node(self):
         task1 = _task('task1')
         task2 = _task('task2')
         f = gf.Flow('test').add(task1)
-        self.assertRaisesRegexp(ValueError, 'Node .* not found to link to',
-                                f.link, task1, task2)
+        self.assertRaisesRegex(ValueError, 'Node .* not found to link to',
+                               f.link, task1, task2)
 
     def test_graph_flow_link_raises_on_cycle(self):
         task1 = _task('task1', provides=['a'])
@@ -267,7 +267,7 @@ class TargetedGraphFlowTest(test.TestCase):
         f.add(task1, task2, task3, task4)
         f.set_target(task3)
         self.assertEqual(3, len(f))
-        self.assertItemsEqual(f, [task1, task2, task3])
+        self.assertCountEqual(f, [task1, task2, task3])
         self.assertNotIn('c', f.provides)
 
     def test_targeted_flow_reset(self):
@@ -280,7 +280,7 @@ class TargetedGraphFlowTest(test.TestCase):
         f.set_target(task3)
         f.reset_target()
         self.assertEqual(4, len(f))
-        self.assertItemsEqual(f, [task1, task2, task3, task4])
+        self.assertCountEqual(f, [task1, task2, task3, task4])
         self.assertIn('c', f.provides)
 
     def test_targeted_flow_bad_target(self):
@@ -288,8 +288,8 @@ class TargetedGraphFlowTest(test.TestCase):
         task1 = _task('task1', provides=['a'], requires=[])
         task2 = _task('task2', provides=['b'], requires=['a'])
         f.add(task1)
-        self.assertRaisesRegexp(ValueError, '^Node .* not found',
-                                f.set_target, task2)
+        self.assertRaisesRegex(ValueError, '^Node .* not found',
+                               f.set_target, task2)
 
     def test_targeted_flow_one_node(self):
         f = gf.TargetedFlow("test")
@@ -297,7 +297,7 @@ class TargetedGraphFlowTest(test.TestCase):
         f.add(task1)
         f.set_target(task1)
         self.assertEqual(1, len(f))
-        self.assertItemsEqual(f, [task1])
+        self.assertCountEqual(f, [task1])
 
     def test_recache_on_add(self):
         f = gf.TargetedFlow("test")
