@@ -28,7 +28,7 @@ class UnorderedFlowTest(test.TestCase):
 
     def test_unordered_flow_stringy(self):
         f = uf.Flow('test')
-        expected = 'unordered_flow.Flow: test(len=0)'
+        expected = '"unordered_flow.Flow: test(len=0)"'
         self.assertEqual(expected, str(f))
 
         task1 = _task(name='task1')
@@ -36,7 +36,7 @@ class UnorderedFlowTest(test.TestCase):
         task3 = _task(name='task3')
         f = uf.Flow('test')
         f.add(task1, task2, task3)
-        expected = 'unordered_flow.Flow: test(len=3)'
+        expected = '"unordered_flow.Flow: test(len=3)"'
         self.assertEqual(expected, str(f))
 
     def test_unordered_flow_starts_as_empty(self):
