@@ -14,8 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
 from oslo_utils import reflection
-import six
 
 from taskflow.engines.worker_based import endpoint
 from taskflow.engines.worker_based import worker
@@ -33,7 +33,6 @@ class TestWorker(test.MockTestCase):
         self.broker_url = 'test-url'
         self.exchange = 'test-exchange'
         self.topic = 'test-topic'
-        self.endpoint_count = 26
 
         # patch classes
         self.executor_mock, self.executor_inst_mock = self.patchClass(
@@ -67,7 +66,7 @@ class TestWorker(test.MockTestCase):
         self.assertEqual(master_mock_calls, self.master_mock.mock_calls)
 
     def test_banner_writing(self):
-        buf = six.StringIO()
+        buf = io.StringIO()
         w = self.worker()
         w.run(banner_writer=buf.write)
         w.wait()
@@ -159,7 +158,7 @@ class TestWorker(test.MockTestCase):
     def test_derive_endpoints_from_string_modules(self):
         endpoints = worker.Worker._derive_endpoints(['taskflow.tests.utils'])
 
-        self.assertEqual(self.endpoint_count, len(endpoints))
+        assert any(e.name == self.task_name for e in endpoints)
 
     def test_derive_endpoints_from_string_non_existent_module(self):
         tasks = ['non.existent.module']
@@ -190,7 +189,7 @@ class TestWorker(test.MockTestCase):
     def test_derive_endpoints_from_modules(self):
         endpoints = worker.Worker._derive_endpoints([utils])
 
-        self.assertEqual(self.endpoint_count, len(endpoints))
+        assert any(e.name == self.task_name for e in endpoints)
 
     def test_derive_endpoints_unexpected_task_type(self):
         self.assertRaises(TypeError, worker.Worker._derive_endpoints, [111])
