@@ -16,17 +16,16 @@
 
 import collections
 import copy
+import io
 import os
 import sys
 import traceback
 
 from oslo_utils import encodeutils
 from oslo_utils import reflection
-import six
 
 from taskflow import exceptions as exc
 from taskflow.utils import iter_utils
-from taskflow.utils import mixins
 from taskflow.utils import schema_utils as su
 
 
@@ -54,7 +53,10 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     # copy_exc_info above.
     if ei1[0] is not ei2[0]:
         return False
-    if not all((type(ei1[1]) == type(ei2[1]),
+    # NOTE(dhellmann): The flake8/pep8 error E721 does not apply here
+    # because we want the types to be exactly the same, not just have
+    # one be inherited from the other.
+    if not all((type(ei1[1]) == type(ei2[1]),  # noqa: E721
                 _exception_message(ei1[1]) == _exception_message(ei2[1]),
                 repr(ei1[1]) == repr(ei2[1]))):
         return False
@@ -65,7 +67,7 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     return tb1 == tb2
 
 
-class Failure(mixins.StrMixin):
+class Failure():
     """An immutable object that represents failure.
 
     Failure objects encapsulate exception information so that they can be
@@ -117,8 +119,8 @@ class Failure(mixins.StrMixin):
       to have code ran when this happens, and this can cause issues and
       side-effects that the receiver would not have intended to have caused).
 
-    TODO(harlowja): use parts of http://bugs.python.org/issue17911 and the
-    backport at https://pypi.python.org/pypi/traceback2/ to (hopefully)
+    TODO(harlowja): use parts of :pybug:`17911` and the
+    backport at https://pypi.org/project/traceback2/ to (hopefully)
     simplify the methods and contents of this object...
     """
     DICT_VERSION = 1
@@ -207,7 +209,7 @@ class Failure(mixins.StrMixin):
             if kwargs:
                 raise TypeError(
                     'Failure.__init__ got unexpected keyword argument(s): %s'
-                    % ', '.join(six.iterkeys(kwargs)))
+                    % ', '.join(kwargs.keys()))
 
     @classmethod
     def from_exception(cls, exception):
@@ -324,7 +326,7 @@ class Failure(mixins.StrMixin):
         """Re-raise exceptions if argument is not empty.
 
         If argument is empty list/tuple/iterator, this method returns
-        None. If argument is coverted into a list with a
+        None. If argument is converted into a list with a
         single ``Failure`` object in it, that failure is reraised. Else, a
         :class:`~taskflow.exceptions.WrappedFailure` exception
         is raised with the failure list as causes.
@@ -340,7 +342,12 @@ class Failure(mixins.StrMixin):
     def reraise(self):
         """Re-raise captured exception."""
         if self._exc_info:
-            six.reraise(*self._exc_info)
+            tp, value, tb = self._exc_info
+            if value is None:
+                value = tp()
+            if value.__traceback__ is not tb:
+                raise value.with_traceback(tb)
+            raise value
         else:
             raise exc.WrappedFailure([self])
 
@@ -378,9 +385,9 @@ class Failure(mixins.StrMixin):
             #
             # See: https://www.python.org/dev/peps/pep-0415/ for why/what
             # the '__suppress_context__' is/means/implies...
-            supress_context = getattr(exc_val,
-                                      '__suppress_context__', False)
-            if supress_context:
+            suppress_context = getattr(exc_val,
+                                       '__suppress_context__', False)
+            if suppress_context:
                 attr_lookups = ['__cause__']
             else:
                 attr_lookups = ['__cause__', '__context__']
@@ -421,12 +428,12 @@ class Failure(mixins.StrMixin):
             self._causes = tuple(self._extract_causes_iter(self.exception))
             return self._causes
 
-    def __unicode__(self):
+    def __str__(self):
         return self.pformat()
 
     def pformat(self, traceback=False):
         """Pretty formats the failure object into a string."""
-        buf = six.StringIO()
+        buf = io.StringIO()
         if not self._exc_type_names:
             buf.write('Failure: %s' % (self._exception_str))
         else:
